<?php
/**
 * Sample code for the CreateNonContractShipment Canada Post service.
 * 
 * The CreateNonContractShipment service is used to generate and pay for a 
 * shipping label, including validation and payment authorization. 
 * 
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 * 
 */

// Your username, password and customer number are imported from the following file    	
// CPCWS_NCShipping_PHP_Samples\REST\noncontractshipping\user.ini
$userProperties = parse_ini_file(realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../user.ini');

$username = $userProperties['username']; 
$password = $userProperties['password'];
$mailedBy = $userProperties['customerNumber'];

// REST URL
$service_url = 'https://ct.soa-gw.canadapost.ca/rs/' . $mailedBy . '/ncshipment';

// Create CreateShipment request xml
$requestedShippingPoint = 'H2B1A0';

$xmlRequest = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<non-contract-shipment xmlns="http://www.canadapost.ca/ws/ncshipment-v4">
	<requested-shipping-point>H2B1A0</requested-shipping-point>
	<delivery-spec>
		<service-code>DOM.EP</service-code>
		<sender>
			<company>Capsule Corp.</company>
			<contact-phone>1 (613) 450-5345</contact-phone>
			<address-details>
				<address-line-1>502 MAIN ST N</address-line-1>
				<city>MONTREAL</city>
				<prov-state>QC</prov-state>
				<postal-zip-code>H2B1A0</postal-zip-code>
			</address-details>
		</sender>
		<destination>
			<name>John Doe</name>
			<company>ACME Corp</company>
			<address-details>
				<address-line-1>123 Postal Drive</address-line-1>
				<city>Ottawa</city>
				<prov-state>ON</prov-state>
				<country-code>CA</country-code>
				<postal-zip-code>K1P5Z9</postal-zip-code>
			</address-details>
		</destination>
		<options>
			<option>
				<option-code>DC</option-code>
			</option>
		</options>
		<parcel-characteristics>
			<weight>15</weight>
			<dimensions>
				<length>1</length>
				<width>1</width>
				<height>1</height>
			</dimensions>
		</parcel-characteristics>
		<preferences>
			<show-packing-instructions>true</show-packing-instructions>
		</preferences>
		<references>
			<cost-centre>ccent</cost-centre>
			<customer-ref-1>custref1</customer-ref-1>
			<customer-ref-2>custref2</customer-ref-2>
	    </references>
	</delivery-spec>
</non-contract-shipment>
XML;

$curl = curl_init($service_url); // Create REST Request
curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 2);
curl_setopt($curl, CURLOPT_CAINFO, realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../../../third-party/cert/cacert.pem'); // Signer Certificate in PEM format
curl_setopt($curl, CURLOPT_POST, true);
curl_setopt($curl, CURLOPT_POSTFIELDS, $xmlRequest);
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
curl_setopt($curl, CURLOPT_USERPWD, $username . ':' . $password);
curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type: application/vnd.cpc.ncshipment-v4+xml', 'Accept: application/vnd.cpc.ncshipment-v4+xml'));
$curl_response = curl_exec($curl); // Execute REST Request
if(curl_errno($curl)){
	echo 'Curl error: ' . curl_error($curl) . "\n";
}

echo 'HTTP Response Status: ' . curl_getinfo($curl,CURLINFO_HTTP_CODE) . "\n";

curl_close($curl);

// Example of using SimpleXML to parse xml response
libxml_use_internal_errors(true);
$xml = simplexml_load_string('<root>' . preg_replace('/<\?xml.*\?>/','',$curl_response) . '</root>');
if (!$xml) {
	echo 'Failed loading XML' . "\n";
	echo $curl_response . "\n";
	foreach(libxml_get_errors() as $error) {
		echo "\t" . $error->message;
	}
} else {	
	if ($xml->{'non-contract-shipment-info'} ) {	
		$shipment = $xml->{'non-contract-shipment-info'}->children('http://www.canadapost.ca/ws/ncshipment-v4');
		if ( $shipment->{'shipment-id'} ) {
			echo 'Shipment ID: ' . $shipment->{'shipment-id'} . "\n";
			foreach ( $shipment->{'links'}->{'link'} as $link ) {  
				echo $link->attributes()->{'rel'} . ': ' . $link->attributes()->{'href'} . "\n";	
			}
		}
	}
	if ($xml->{'messages'} ) {					
		$messages = $xml->{'messages'}->children('http://www.canadapost.ca/ws/messages');		
		foreach ( $messages as $message ) {
			echo 'Error Code: ' . $message->code . "\n";
			echo 'Error Msg: ' . $message->description . "\n\n";
		}
	}
}

?>

